//
//  main.c
//  Example using MFS as UART
//
//  Created by Manuel Schreiner on 17.04.16,
//  Copyright © 2016 io-expert.com. All rights reserved.
//
/*******************************************************************************/
//                                                                             //
//   IIIII    OOO       EEE  X  X  PPP  EEE  RRR  TTTTT       CCC  OOO  M   M  //
//  I     I  O   O      E    X  X  P  P E    R  R   T        C    O   O MM MM  //
//   I M I   O   O  --  EEE   XX   PPP  EEE  RRR    T        C    O   O M M M  //
//    III    O   O      E    X  X  P    E    R  R   T        C    O   O M   M  //
//    III     OOO       EEE  X  X  P    EEE  R  R   T   DOT   CCC  OOO  M   M  //
//                                                                             //
/*******************************************************************************/
//
// 1. Redistributions of source code must retain the above copyright notice,
//    this condition and the following disclaimer.
//
// This software is provided by the copyright holder and contributors "AS IS"
// and any warranties related to this software are DISCLAIMED.
// The copyright owner or contributors be NOT LIABLE for any damages caused
// by use of this software.
//
/******************************************************************************/
/** \file main.c
 **
 ** \brief Base Timer PWM Example
 **
 ** Main Module
 **
 ** History:
 **   - 2016-04-17  First Version
 **
 ******************************************************************************/

/******************************************************************************/
/* Include files                                                              */
/******************************************************************************/
#include "mcu.h"
#include "iomux.h"

#ifndef FM_BT_AVAILABLE // check if base timer is available
    #error This example requires the BT peripheral which is not available for this device
#endif

#ifndef SetPinFunc_TIOA0_1_OUT //check TIOA0_1 is available
   #error Please change SetPinFunc_TIOA0_1_OUT to an existing pin
#endif

#define FREQUENCY_HZ      1000u
#define PCSR_VAL          (((__HCLK / 4u) / FREQUENCY_HZ) - 1u)

/**
 ******************************************************************************
 ** \brief   Initialization of Base Timer for PWM signal generation
 **
 ** \param  stcBt Base Timer (BT) peripheral
 **
 ******************************************************************************/
static void InitBT(FM_BT_PWM_TypeDef* stcBt)
{
  FM_BTIOSEL03->BTSEL0123 = 0x00u;          // I/O mode 0 (Standard 16-bit timer mode))
  
  stcBt->TMCR  = 0x1012u;                   // PCLK / 4, PWM function, continuous operation, operation enabled
  stcBt->TMCR2 = 0x00u;
  stcBt->STC   = 0x00u;                     // Disable all interrupts
  stcBt->PCSR  = PCSR_VAL;                  // PWM Cycle Set Register (PCSR)   
  stcBt->PDUT  = (uint16_t)PCSR_VAL / 2u;   // PWM Duty Cycle set to 50%
  
  stcBt->TMCR_f.STRG = 1u;                  // Start timer using software trigger
}

/**
 ******************************************************************************
 ** \brief  Main function
 **
 ** \return int32_t return value, if needed
 ******************************************************************************/
int main(void)
{
  SetPinFunc_TIOA0_1_OUT();
  InitBT(FM_BT0_PWM);
  while(1u)
  {}
}
/******************************************************************************/
/* EOF (not truncated)                                                        */
/******************************************************************************/